<?php
header('Access-Control-Allow-Origin: *');

session_start();
require_once ("db.inc.php");
require_once ("authenticate.inc.php");
require_once ("funzioni.inc.php"); 

new API();

class API{
	
	private $Conn;
	private $prefix;
	
	function __construct(){
		$this->prefix = 'wcrs_';
		$action = isset($_GET['q']) ? $_GET['q'] : '';
		$this->task_manager($action);
	}
	
	function task_manager($action = ''){
		if($this->validate()){
			switch($action){
				case 'getCount' : $this->getTotalCount(); break;
				case 'getUsers' : $this->getUsers(); break;
				case '':
				default: $this->error_handler(404);
			}
		}
		else{
			$this->error_handler(401);
		}
	}
	
	function ResponseHandler($array){
		$status = $array['status']; 
		
		if( isset($array['message']) )
			$message = $array['message'];
		else
			$message = $this->GetStatusMessage($array['status']);
		
		header("HTTP/1.1 $status $message");
		header("Content-Type: application/json");
		$array['message'] = $message;
		echo json_encode($array);
	}
	
	/* response handler messages */
	function GetStatusMessage($status){
		$ResponseHandlerMessage = array(
			200 => 'OK',
			202 => 'SQL Error Occured',
			204 => 'Data Not Found',
			400 => 'Bad Request',
			401 => 'Unauthorized',
			404 => 'Page Not Found',
			503 => 'Service Unavailable'
		);
		return $ResponseHandlerMessage[$status];
	}
	
	/* error handler for request */
	function error_handler($status, $message = null){
		$return['status'] = $status;
		$return['data'] = null;
		if($message != null)
			$return['message'] = $message;
		$this->ResponseHandler($return);
	}
	
	/* success handler for request */
	function success_handler($data){
		$return['status'] = $data['status'];
		$return['data'] = $data['data'];
		$this->ResponseHandler($return);
	}
	
	
	function getTotalCount(){
		$table = $this->prefix . $_REQUEST['countof'];
		if($this->check_request_method('GET')){
			if($this->open()){
				$result = $this->execute_query( $this->Conn, "select count(*) as num_rows from $table" );
				$row = mysqli_fetch_object($result);
				$total = $row->num_rows;
				$this->close();
				
				$this->success_handler(array('status'=>200, 'data'=>array('total'=>$total)));
				
			}else{
				$this->error_handler(202);
			}
		}else{
			$this->error_handler(400);
		}
	}
	
	function getUsers(){
		$table = $this->prefix . 'users';
		$filters = (array)json_decode($_GET['filters']);		
		//print_r($filters);
		//echo $filters->filtro_utente;
		
		
		if($this->check_request_method('GET')){
			
			if($this->open()){
			$subQuery = '';
			if(array_key_exists('filtro_utente', $filters) && $filters['filtro_utente'] != ''){
				$subQuery .= " AND LCASE(CONCAT(last_name, ' ', first_name)) LIKE '%" . strtolower($filters['filtro_utente']) . "%'";
			}
			
			if(array_key_exists('filtro_email', $filters) && $filters['filtro_email'] != ''){
				$subQuery .= " AND LCASE(email) LIKE '%" . strtolower($filters['filtro_email']) . "%'";
			}
			
			if(array_key_exists('filtro_regdate_from', $filters) && $filters['filtro_regdate_from'] != ''){
				//$subQuery .= " AND DATE_FORMAT(STR_TO_DATE(date_registration, '%Y-%m-%d'), '%M %D %Y')  >= ".$this->sql_quote($this->Conn,$filters['filtro_regdate_from']);
				$subQuery .= " AND date_registration  >= ".$this->sql_quote($this->Conn,Date('Y-m-d', strtotime($filters['filtro_regdate_from'])));
			}
			
			if(array_key_exists('filtro_regdate_to', $filters) && $filters['filtro_regdate_to'] != '') {
				$subQuery .= " AND date_registration <= ".$this->sql_quote($this->Conn,Date('Y-m-d', strtotime($filters['filtro_regdate_to'])));
			}
			
			if(array_key_exists('filtro_paiddate_from', $filters) && $filters['filtro_paiddate_from'] != ''){
				$subQuery .= " AND DATE_FORMAT(STR_TO_DATE(pay_date, '%H:%i:%s %M %d, %Y'), '%M %D %Y') >= ".$this->sql_quote($this->Conn,$filters['filtro_paiddate_from']);
			}
			
			if(array_key_exists('filtro_paiddate_to', $filters) && $filters['filtro_paiddate_to'] != ''){
				$subQuery .= " AND DATE_FORMAT(STR_TO_DATE(pay_date, '%H:%i:%s %M %d, %Y'), '%M %D %Y') <= ".$this->sql_quote($this->Conn,$filters['filtro_paiddate_to']);
			}
			
			if(array_key_exists('filtro_expdate_from', $filters) && $filters['filtro_expdate_from'] != ''){
				$subQuery .= " AND pay_expire >= ".$this->sql_quote($this->Conn,Date('Y-m-d', strtotime($filters['filtro_expdate_from'])));
			}
			
			if(array_key_exists('filtro_expdate_to', $filters) && $filters['filtro_expdate_to'] != ''){
				$subQuery .= " AND pay_expire <= ".$this->sql_quote($this->Conn,Date('Y-m-d', strtotime($filters['filtro_expdate_to'])));
			}
			
			if(array_key_exists('filtro_status', $filters) && $filters['filtro_status'] != '-1'){
				$subQuery .= " AND active = ".$this->sql_quote($this->Conn,$filters['filtro_status']);
			}
			
			if(array_key_exists('filtro_level', $filters) && $filters['filtro_level'] != ''){
				$subQuery .= " AND level = ".$this->sql_quote($this->Conn,$filters['filtro_level']);
			}	
			
			if(array_key_exists('filtro_payfr', $filters) && $filters['filtro_payfr'] != '-1'){
				$subQuery .= " AND pay_frequency = ".$this->sql_quote($this->Conn,$filters['filtro_payfr']);
			}	
			
			if(array_key_exists('filtro_expire', $filters) && $filters['filtro_expire'] != ''){
				$subQuery .= " AND pay_expire <= DATE_SUB(NOW(), INTERVAL 10 DAY)";
			}
			
			$sql = "select id, CONCAT(last_name,' ', first_name) as utente, email, date_registration, 
			CASE
				WHEN level=1 THEN 'Standard membership'
				WHEN level=2 THEN 'Premium membership'
				WHEN level=5 THEN 'Free membership'
				WHEN level=3 THEN 'Trade membership'
				ELSE ''
			END as level
			, 
			CASE 
				WHEN life_member=1 THEN 'YES'
				WHEN life_member=0 THEN 'NO'
				ELSE ''
			END as life_member
			, pay_date, 
			CASE 
				WHEN active=1 THEN 'ok'
				WHEN active=0 THEN 'remove'
				ELSE ''
			END as active,subscr_id, pay_frequency, 
			CASE 
				WHEN pay_date<>'' and subscr_id<>'' and pay_frequency <> '' THEN  
					CASE 
						WHEN pay_frequency='1 M' THEN  
							DATE_FORMAT(DATE_ADD(STR_TO_DATE(pay_date, '%H:%i:%s %M %d, %Y'), INTERVAL 40 DAY), '%Y-%m-%d')
						WHEN pay_frequency='2 M' THEN
							DATE_FORMAT(DATE_ADD(STR_TO_DATE(pay_date, '%H:%i:%s %M %d, %Y'), INTERVAL 70 DAY), '%Y-%m-%d')
						WHEN pay_frequency='3 M' THEN
							DATE_FORMAT(DATE_ADD(STR_TO_DATE(pay_date, '%H:%i:%s %M %d, %Y'), INTERVAL 100 DAY), '%Y-%m-%d')
						ELSE
							''
					END 
				ELSE '' 
			END as pay_next 
			FROM $table
			WHERE 1 $subQuery";
			echo $sql;
			
			//if($this->open()){
				$result = $this->select_row( $this->Conn, $sql );
				$this->close();
				
				$this->success_handler(array('status'=>200, 'data'=>$result));
				
			}else{
				$this->error_handler(202);
			}
		}else{
			$this->error_handler(400);
		}
	}
	
	function validate(){
		if(checkSessione() == false){
			return false;
		}
		return true;
	}
	
	/* open DB Connection */
	function open(){
		$this->Conn = mysqli_connect(DB_HOSTNAME, DB_USERNAME, DB_PASSWORD, DB_DATABASE);
		if (!$this->Conn){
			return false;
		}else{
			@mysqli_query($this->Conn,"SET NAMES 'utf8'");
			return true;
		}
	}
	
	/* close DB Connection */
	function close(){
		if( $this->Conn )
			@mysqli_close($this->Conn);
	}
	
	/* select rows from Table */
	function select_row($db, $sql){
		if ($sql!=""){
			$data = array();
			if ($result = @mysqli_query($db, $sql)){
				while($row = @mysqli_fetch_assoc($result)){
					$data[] = $row;
				}
				return $data;
			}
		}
	}
	
	/* avoid sql injection */
	function sql_quote($db, $value){
		if (function_exists('get_magic_quotes_gpc') && get_magic_quotes_gpc()) {
			$value = stripslashes($value);
		}
	    if (!is_numeric($value)) {
		   $value = "'" . mysqli_real_escape_string($db,$value) . "'";
	    }
	   return $value;
	}
	
	/* execute sql query */
	function execute_query($db, $sql){
		if($db && $sql)
			return mysqli_query($db, $sql);
		else
			return false;
	}
	
	/* check request method */
	function check_request_method($method){
		if (strtoupper($_SERVER['REQUEST_METHOD']) != $method){
			return false;
		}else{
			return true;
		}
	}

}


?>