<?php
// webhook.php
//
// Use this sample code to handle webhook events in your integration.
//
// 1) Paste this code into a new file (webhook.php)
//
// 2) Install dependencies
//   composer require stripe/stripe-php
//
// 3) Run the server on http://localhost:4242
//   php -S localhost:4242

date_default_timezone_set('America/Barbados');
echo date_default_timezone_get();
//die;

require './autoload.php';
require './stripe-service.php';

// This is your Stripe CLI webhook secret for testing your endpoint locally.
//$endpoint_secret = 'whsec_67a9ba385d3a0e898718d6ca80ce67c5bd89c125ff40433eaf1f836fb5bf5824';
$endpoint_secret = 'whsec_Dtvj8qZFQQEOHJBuddC7vEAYNd4le0ys';

$payload = @file_get_contents('php://input');
$sig_header = $_SERVER['HTTP_STRIPE_SIGNATURE'];
$event = null;

file_put_contents("payload.txt", $payload);
file_put_contents("sig_header.txt", $sig_header);

try {
  $event = \Stripe\Webhook::constructEvent(
    $payload, $sig_header, $endpoint_secret
  );
} catch(\UnexpectedValueException $e) {
  // Invalid payload
  file_put_contents("invalid.txt", $e);
  http_response_code(400);
  exit();
} catch(\Stripe\Exception\SignatureVerificationException $e) {
  // Invalid signature
    file_put_contents("invalid.txt", $e);
  http_response_code(400);
  exit();
}

// Handle the event
switch ($event->type) {
  case 'customer.created':
    $customer = $event->data->object;
    //file_put_contents("customer.txt", json_encode($customer));
    $stripeService->insertCustomer($customer);
    break;
  case 'customer.subscription.created':
    $subscription = $event->data->object;
    //file_put_contents("subscription.txt", json_encode($subscription));
    $stripeService->insertSubscription($subscription);
    break;
  case 'customer.subscription.deleted':
    $subscription = $event->data->object;
    //file_put_contents("subscription_del.txt", json_encode($subscription));
    $stripeService->cancelSubscription($subscription);
    break;
  case 'customer.subscription.updated':
    $subscription = $event->data->object;
    //file_put_contents("subscription_up.txt", json_encode($subscription));
    $stripeService->updateSubscription($subscription);
    break;
  case 'invoice.created':
    $invoice = $event->data->object;
    //file_put_contents("inv_cre.txt", json_encode($invoice));
    $stripeService->invoiceCreated($invoice);
    break;
  case 'invoice.finalized':
    $invoice = $event->data->object;
    //file_put_contents("inv_fi.txt", json_encode($invoice));
    $stripeService->invoiceFinalized($invoice);
    break;
  case 'invoice.payment_failed':
    $invoice = $event->data->object;
    //file_put_contents("inv_fa.txt", json_encode($invoice));
    $stripeService->updateInvoiceStatus($invoice);
    $stripeService->paymentFailedNotification($invoice);
    break;
  case 'invoice.payment_succeeded':
    $invoice = $event->data->object;
    //file_put_contents("inv_succ.txt", json_encode($invoice));
    $stripeService->updateInvoiceStatus($invoice);
    $stripeService->invoicePaymentSuccess($invoice);
    break;
  default:
    echo 'Received unknown event type ' . $event->type;
    break;
}

http_response_code(200);